@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ordered-set" "0.2.1"
+(define-package "ordered-set" "20250616.1432"
   "Insertion-order sets."
   '((emacs "25.3")
     (seq   "2.23"))
